# coding: utf-8

# flake8: noqa

"""
    Pipelines

    Pipelines represent distinct stages in a workflow, like closing a deal or servicing a support ticket. These endpoints provide access to read and modify pipelines in HubSpot. Pipelines support `deals` and `tickets` object types.  ## Pipeline ID validation  When calling endpoints that take pipelineId as a parameter, that ID must correspond to an existing, un-archived pipeline. Otherwise the request will fail with a `404 Not Found` response.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.pipelines.api.pipeline_audits_api import PipelineAuditsApi
from hubspot.crm.pipelines.api.pipeline_stage_audits_api import PipelineStageAuditsApi
from hubspot.crm.pipelines.api.pipeline_stages_api import PipelineStagesApi
from hubspot.crm.pipelines.api.pipelines_api import PipelinesApi

# import ApiClient
from hubspot.crm.pipelines.api_client import ApiClient
from hubspot.crm.pipelines.configuration import Configuration
from hubspot.crm.pipelines.exceptions import OpenApiException
from hubspot.crm.pipelines.exceptions import ApiTypeError
from hubspot.crm.pipelines.exceptions import ApiValueError
from hubspot.crm.pipelines.exceptions import ApiKeyError
from hubspot.crm.pipelines.exceptions import ApiAttributeError
from hubspot.crm.pipelines.exceptions import ApiException

# import models into sdk package
from hubspot.crm.pipelines.models.collection_response_pipeline_no_paging import CollectionResponsePipelineNoPaging
from hubspot.crm.pipelines.models.collection_response_pipeline_stage_no_paging import CollectionResponsePipelineStageNoPaging
from hubspot.crm.pipelines.models.collection_response_public_audit_info_no_paging import CollectionResponsePublicAuditInfoNoPaging
from hubspot.crm.pipelines.models.error import Error
from hubspot.crm.pipelines.models.error_detail import ErrorDetail
from hubspot.crm.pipelines.models.pipeline import Pipeline
from hubspot.crm.pipelines.models.pipeline_input import PipelineInput
from hubspot.crm.pipelines.models.pipeline_patch_input import PipelinePatchInput
from hubspot.crm.pipelines.models.pipeline_stage import PipelineStage
from hubspot.crm.pipelines.models.pipeline_stage_input import PipelineStageInput
from hubspot.crm.pipelines.models.pipeline_stage_patch_input import PipelineStagePatchInput
from hubspot.crm.pipelines.models.public_audit_info import PublicAuditInfo
