# coding: utf-8

"""
    Hubdb

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.hubdb.configuration import Configuration


class Option(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "created_by_user_id": "int",
        "created_at": "datetime",
        "updated_by": "SimpleUser",
        "created_by": "SimpleUser",
        "name": "str",
        "id": "str",
        "label": "str",
        "updated_by_user_id": "int",
        "type": "str",
        "order": "int",
        "updated_at": "datetime",
    }

    attribute_map = {
        "created_by_user_id": "createdByUserId",
        "created_at": "createdAt",
        "updated_by": "updatedBy",
        "created_by": "createdBy",
        "name": "name",
        "id": "id",
        "label": "label",
        "updated_by_user_id": "updatedByUserId",
        "type": "type",
        "order": "order",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        created_by_user_id=None,
        created_at=None,
        updated_by=None,
        created_by=None,
        name=None,
        id=None,
        label=None,
        updated_by_user_id=None,
        type=None,
        order=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Option - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_by_user_id = None
        self._created_at = None
        self._updated_by = None
        self._created_by = None
        self._name = None
        self._id = None
        self._label = None
        self._updated_by_user_id = None
        self._type = None
        self._order = None
        self._updated_at = None
        self.discriminator = None

        if created_by_user_id is not None:
            self.created_by_user_id = created_by_user_id
        self.created_at = created_at
        if updated_by is not None:
            self.updated_by = updated_by
        if created_by is not None:
            self.created_by = created_by
        self.name = name
        self.id = id
        if label is not None:
            self.label = label
        if updated_by_user_id is not None:
            self.updated_by_user_id = updated_by_user_id
        self.type = type
        self.order = order
        self.updated_at = updated_at

    @property
    def created_by_user_id(self):
        """Gets the created_by_user_id of this Option.  # noqa: E501


        :return: The created_by_user_id of this Option.  # noqa: E501
        :rtype: int
        """
        return self._created_by_user_id

    @created_by_user_id.setter
    def created_by_user_id(self, created_by_user_id):
        """Sets the created_by_user_id of this Option.


        :param created_by_user_id: The created_by_user_id of this Option.  # noqa: E501
        :type created_by_user_id: int
        """

        self._created_by_user_id = created_by_user_id

    @property
    def created_at(self):
        """Gets the created_at of this Option.  # noqa: E501


        :return: The created_at of this Option.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Option.


        :param created_at: The created_at of this Option.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_by(self):
        """Gets the updated_by of this Option.  # noqa: E501


        :return: The updated_by of this Option.  # noqa: E501
        :rtype: SimpleUser
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this Option.


        :param updated_by: The updated_by of this Option.  # noqa: E501
        :type updated_by: SimpleUser
        """

        self._updated_by = updated_by

    @property
    def created_by(self):
        """Gets the created_by of this Option.  # noqa: E501


        :return: The created_by of this Option.  # noqa: E501
        :rtype: SimpleUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Option.


        :param created_by: The created_by of this Option.  # noqa: E501
        :type created_by: SimpleUser
        """

        self._created_by = created_by

    @property
    def name(self):
        """Gets the name of this Option.  # noqa: E501

          # noqa: E501

        :return: The name of this Option.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Option.

          # noqa: E501

        :param name: The name of this Option.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def id(self):
        """Gets the id of this Option.  # noqa: E501

          # noqa: E501

        :return: The id of this Option.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Option.

          # noqa: E501

        :param id: The id of this Option.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def label(self):
        """Gets the label of this Option.  # noqa: E501


        :return: The label of this Option.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this Option.


        :param label: The label of this Option.  # noqa: E501
        :type label: str
        """

        self._label = label

    @property
    def updated_by_user_id(self):
        """Gets the updated_by_user_id of this Option.  # noqa: E501


        :return: The updated_by_user_id of this Option.  # noqa: E501
        :rtype: int
        """
        return self._updated_by_user_id

    @updated_by_user_id.setter
    def updated_by_user_id(self, updated_by_user_id):
        """Sets the updated_by_user_id of this Option.


        :param updated_by_user_id: The updated_by_user_id of this Option.  # noqa: E501
        :type updated_by_user_id: int
        """

        self._updated_by_user_id = updated_by_user_id

    @property
    def type(self):
        """Gets the type of this Option.  # noqa: E501

          # noqa: E501

        :return: The type of this Option.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Option.

          # noqa: E501

        :param type: The type of this Option.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def order(self):
        """Gets the order of this Option.  # noqa: E501

          # noqa: E501

        :return: The order of this Option.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this Option.

          # noqa: E501

        :param order: The order of this Option.  # noqa: E501
        :type order: int
        """
        if self.local_vars_configuration.client_side_validation and order is None:  # noqa: E501
            raise ValueError("Invalid value for `order`, must not be `None`")  # noqa: E501

        self._order = order

    @property
    def updated_at(self):
        """Gets the updated_at of this Option.  # noqa: E501


        :return: The updated_at of this Option.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Option.


        :param updated_at: The updated_at of this Option.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Option):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Option):
            return True

        return self.to_dict() != other.to_dict()
