# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicAndFilterBranch(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "filter_branch_type": "str",
        "filter_branches": "list[PublicPropertyAssociationFilterBranchFilterBranchesInner]",
        "filter_branch_operator": "str",
        "filters": "list[PublicPropertyAssociationFilterBranchFiltersInner]",
    }

    attribute_map = {"filter_branch_type": "filterBranchType", "filter_branches": "filterBranches", "filter_branch_operator": "filterBranchOperator", "filters": "filters"}

    def __init__(self, filter_branch_type="AND", filter_branches=None, filter_branch_operator=None, filters=None, local_vars_configuration=None):  # noqa: E501
        """PublicAndFilterBranch - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._filter_branch_type = None
        self._filter_branches = None
        self._filter_branch_operator = None
        self._filters = None
        self.discriminator = None

        self.filter_branch_type = filter_branch_type
        self.filter_branches = filter_branches
        self.filter_branch_operator = filter_branch_operator
        self.filters = filters

    @property
    def filter_branch_type(self):
        """Gets the filter_branch_type of this PublicAndFilterBranch.  # noqa: E501


        :return: The filter_branch_type of this PublicAndFilterBranch.  # noqa: E501
        :rtype: str
        """
        return self._filter_branch_type

    @filter_branch_type.setter
    def filter_branch_type(self, filter_branch_type):
        """Sets the filter_branch_type of this PublicAndFilterBranch.


        :param filter_branch_type: The filter_branch_type of this PublicAndFilterBranch.  # noqa: E501
        :type filter_branch_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_branch_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_branch_type`, must not be `None`")  # noqa: E501
        allowed_values = ["AND"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_branch_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_branch_type` ({0}), must be one of {1}".format(filter_branch_type, allowed_values))  # noqa: E501

        self._filter_branch_type = filter_branch_type

    @property
    def filter_branches(self):
        """Gets the filter_branches of this PublicAndFilterBranch.  # noqa: E501


        :return: The filter_branches of this PublicAndFilterBranch.  # noqa: E501
        :rtype: list[PublicPropertyAssociationFilterBranchFilterBranchesInner]
        """
        return self._filter_branches

    @filter_branches.setter
    def filter_branches(self, filter_branches):
        """Sets the filter_branches of this PublicAndFilterBranch.


        :param filter_branches: The filter_branches of this PublicAndFilterBranch.  # noqa: E501
        :type filter_branches: list[PublicPropertyAssociationFilterBranchFilterBranchesInner]
        """
        if self.local_vars_configuration.client_side_validation and filter_branches is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_branches`, must not be `None`")  # noqa: E501

        self._filter_branches = filter_branches

    @property
    def filter_branch_operator(self):
        """Gets the filter_branch_operator of this PublicAndFilterBranch.  # noqa: E501


        :return: The filter_branch_operator of this PublicAndFilterBranch.  # noqa: E501
        :rtype: str
        """
        return self._filter_branch_operator

    @filter_branch_operator.setter
    def filter_branch_operator(self, filter_branch_operator):
        """Sets the filter_branch_operator of this PublicAndFilterBranch.


        :param filter_branch_operator: The filter_branch_operator of this PublicAndFilterBranch.  # noqa: E501
        :type filter_branch_operator: str
        """
        if self.local_vars_configuration.client_side_validation and filter_branch_operator is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_branch_operator`, must not be `None`")  # noqa: E501

        self._filter_branch_operator = filter_branch_operator

    @property
    def filters(self):
        """Gets the filters of this PublicAndFilterBranch.  # noqa: E501


        :return: The filters of this PublicAndFilterBranch.  # noqa: E501
        :rtype: list[PublicPropertyAssociationFilterBranchFiltersInner]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this PublicAndFilterBranch.


        :param filters: The filters of this PublicAndFilterBranch.  # noqa: E501
        :type filters: list[PublicPropertyAssociationFilterBranchFiltersInner]
        """
        if self.local_vars_configuration.client_side_validation and filters is None:  # noqa: E501
            raise ValueError("Invalid value for `filters`, must not be `None`")  # noqa: E501

        self._filters = filters

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicAndFilterBranch):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicAndFilterBranch):
            return True

        return self.to_dict() != other.to_dict()
