# coding: utf-8

# flake8: noqa
"""
    Visitor Identification

    The Visitor Identification API allows you to pass identification information to the HubSpot chat widget for otherwise unknown visitors that were verified by your own authentication system.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.conversations.visitor_identification.models.error import Error
from hubspot.conversations.visitor_identification.models.error_detail import ErrorDetail
from hubspot.conversations.visitor_identification.models.identification_token_generation_request import IdentificationTokenGenerationRequest
from hubspot.conversations.visitor_identification.models.identification_token_response import IdentificationTokenResponse
