# coding: utf-8

# flake8: noqa

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.marketing.emails.api.marketing_emails_api import MarketingEmailsApi
from hubspot.marketing.emails.api.statistics_api import StatisticsApi

# import ApiClient
from hubspot.marketing.emails.api_client import ApiClient
from hubspot.marketing.emails.configuration import Configuration
from hubspot.marketing.emails.exceptions import OpenApiException
from hubspot.marketing.emails.exceptions import ApiTypeError
from hubspot.marketing.emails.exceptions import ApiValueError
from hubspot.marketing.emails.exceptions import ApiKeyError
from hubspot.marketing.emails.exceptions import ApiAttributeError
from hubspot.marketing.emails.exceptions import ApiException

# import models into sdk package
from hubspot.marketing.emails.models.ab_test_create_request_v_next import AbTestCreateRequestVNext
from hubspot.marketing.emails.models.aggregate_email_statistics import AggregateEmailStatistics
from hubspot.marketing.emails.models.collection_response_with_total_email_statistic_interval_no_paging import CollectionResponseWithTotalEmailStatisticIntervalNoPaging
from hubspot.marketing.emails.models.collection_response_with_total_public_email_forward_paging import CollectionResponseWithTotalPublicEmailForwardPaging
from hubspot.marketing.emails.models.collection_response_with_total_version_public_email import CollectionResponseWithTotalVersionPublicEmail
from hubspot.marketing.emails.models.content_clone_request_v_next import ContentCloneRequestVNext
from hubspot.marketing.emails.models.email_create_request import EmailCreateRequest
from hubspot.marketing.emails.models.email_statistic_interval import EmailStatisticInterval
from hubspot.marketing.emails.models.email_statistics_data import EmailStatisticsData
from hubspot.marketing.emails.models.email_update_request import EmailUpdateRequest
from hubspot.marketing.emails.models.error import Error
from hubspot.marketing.emails.models.error_detail import ErrorDetail
from hubspot.marketing.emails.models.forward_paging import ForwardPaging
from hubspot.marketing.emails.models.interval import Interval
from hubspot.marketing.emails.models.next_page import NextPage
from hubspot.marketing.emails.models.paging import Paging
from hubspot.marketing.emails.models.previous_page import PreviousPage
from hubspot.marketing.emails.models.public_button_style_settings import PublicButtonStyleSettings
from hubspot.marketing.emails.models.public_divider_style_settings import PublicDividerStyleSettings
from hubspot.marketing.emails.models.public_email import PublicEmail
from hubspot.marketing.emails.models.public_email_content import PublicEmailContent
from hubspot.marketing.emails.models.public_email_from_details import PublicEmailFromDetails
from hubspot.marketing.emails.models.public_email_recipients import PublicEmailRecipients
from hubspot.marketing.emails.models.public_email_style_settings import PublicEmailStyleSettings
from hubspot.marketing.emails.models.public_email_subscription_details import PublicEmailSubscriptionDetails
from hubspot.marketing.emails.models.public_email_testing_details import PublicEmailTestingDetails
from hubspot.marketing.emails.models.public_email_to_details import PublicEmailToDetails
from hubspot.marketing.emails.models.public_font_style import PublicFontStyle
from hubspot.marketing.emails.models.public_rss_email_details import PublicRssEmailDetails
from hubspot.marketing.emails.models.public_webversion_details import PublicWebversionDetails
from hubspot.marketing.emails.models.version_public_email import VersionPublicEmail
from hubspot.marketing.emails.models.version_user import VersionUser
