# coding: utf-8

# flake8: noqa
"""
    Events Send Event Completions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.events.send.models.batched_behavioral_event_http_completion_request import BatchedBehavioralEventHttpCompletionRequest
from hubspot.events.send.models.behavioral_event_http_completion_request import BehavioralEventHttpCompletionRequest
from hubspot.events.send.models.error import Error
from hubspot.events.send.models.error_detail import ErrorDetail
