# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicFormSubmissionOnPageFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "form_id": "str",
        "coalescing_refine_by": "PublicFormSubmissionFilterCoalescingRefineBy",
        "pruning_refine_by": "PublicFormSubmissionFilterCoalescingRefineBy",
        "filter_type": "str",
        "page_id": "str",
        "operator": "str",
    }

    attribute_map = {
        "form_id": "formId",
        "coalescing_refine_by": "coalescingRefineBy",
        "pruning_refine_by": "pruningRefineBy",
        "filter_type": "filterType",
        "page_id": "pageId",
        "operator": "operator",
    }

    def __init__(
        self, form_id=None, coalescing_refine_by=None, pruning_refine_by=None, filter_type="FORM_SUBMISSION_ON_PAGE", page_id=None, operator=None, local_vars_configuration=None
    ):  # noqa: E501
        """PublicFormSubmissionOnPageFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._form_id = None
        self._coalescing_refine_by = None
        self._pruning_refine_by = None
        self._filter_type = None
        self._page_id = None
        self._operator = None
        self.discriminator = None

        if form_id is not None:
            self.form_id = form_id
        if coalescing_refine_by is not None:
            self.coalescing_refine_by = coalescing_refine_by
        if pruning_refine_by is not None:
            self.pruning_refine_by = pruning_refine_by
        self.filter_type = filter_type
        self.page_id = page_id
        self.operator = operator

    @property
    def form_id(self):
        """Gets the form_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The form_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: str
        """
        return self._form_id

    @form_id.setter
    def form_id(self, form_id):
        """Sets the form_id of this PublicFormSubmissionOnPageFilter.


        :param form_id: The form_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type form_id: str
        """

        self._form_id = form_id

    @property
    def coalescing_refine_by(self):
        """Gets the coalescing_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The coalescing_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: PublicFormSubmissionFilterCoalescingRefineBy
        """
        return self._coalescing_refine_by

    @coalescing_refine_by.setter
    def coalescing_refine_by(self, coalescing_refine_by):
        """Sets the coalescing_refine_by of this PublicFormSubmissionOnPageFilter.


        :param coalescing_refine_by: The coalescing_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type coalescing_refine_by: PublicFormSubmissionFilterCoalescingRefineBy
        """

        self._coalescing_refine_by = coalescing_refine_by

    @property
    def pruning_refine_by(self):
        """Gets the pruning_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The pruning_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: PublicFormSubmissionFilterCoalescingRefineBy
        """
        return self._pruning_refine_by

    @pruning_refine_by.setter
    def pruning_refine_by(self, pruning_refine_by):
        """Sets the pruning_refine_by of this PublicFormSubmissionOnPageFilter.


        :param pruning_refine_by: The pruning_refine_by of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type pruning_refine_by: PublicFormSubmissionFilterCoalescingRefineBy
        """

        self._pruning_refine_by = pruning_refine_by

    @property
    def filter_type(self):
        """Gets the filter_type of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The filter_type of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """Sets the filter_type of this PublicFormSubmissionOnPageFilter.


        :param filter_type: The filter_type of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type filter_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_type`, must not be `None`")  # noqa: E501
        allowed_values = ["FORM_SUBMISSION_ON_PAGE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_type` ({0}), must be one of {1}".format(filter_type, allowed_values))  # noqa: E501

        self._filter_type = filter_type

    @property
    def page_id(self):
        """Gets the page_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The page_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this PublicFormSubmissionOnPageFilter.


        :param page_id: The page_id of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type page_id: str
        """
        if self.local_vars_configuration.client_side_validation and page_id is None:  # noqa: E501
            raise ValueError("Invalid value for `page_id`, must not be `None`")  # noqa: E501

        self._page_id = page_id

    @property
    def operator(self):
        """Gets the operator of this PublicFormSubmissionOnPageFilter.  # noqa: E501


        :return: The operator of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicFormSubmissionOnPageFilter.


        :param operator: The operator of this PublicFormSubmissionOnPageFilter.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501
        allowed_values = ["FILLED_OUT", "NOT_FILLED_OUT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `operator` ({0}), must be one of {1}".format(operator, allowed_values))  # noqa: E501

        self._operator = operator

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicFormSubmissionOnPageFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicFormSubmissionOnPageFilter):
            return True

        return self.to_dict() != other.to_dict()
