# coding: utf-8

# flake8: noqa

"""
    CRM Deal Splits

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.objects.deal_splits.api.batch_api import BatchApi

# import ApiClient
from hubspot.crm.objects.deal_splits.api_client import ApiClient
from hubspot.crm.objects.deal_splits.configuration import Configuration
from hubspot.crm.objects.deal_splits.exceptions import OpenApiException
from hubspot.crm.objects.deal_splits.exceptions import ApiTypeError
from hubspot.crm.objects.deal_splits.exceptions import ApiValueError
from hubspot.crm.objects.deal_splits.exceptions import ApiKeyError
from hubspot.crm.objects.deal_splits.exceptions import ApiAttributeError
from hubspot.crm.objects.deal_splits.exceptions import ApiException

# import models into sdk package
from hubspot.crm.objects.deal_splits.models.batch_input_public_object_id import BatchInputPublicObjectId
from hubspot.crm.objects.deal_splits.models.batch_response_deal_to_deal_splits import BatchResponseDealToDealSplits
from hubspot.crm.objects.deal_splits.models.batch_response_deal_to_deal_splits_with_errors import BatchResponseDealToDealSplitsWithErrors
from hubspot.crm.objects.deal_splits.models.deal_to_deal_splits import DealToDealSplits
from hubspot.crm.objects.deal_splits.models.error import Error
from hubspot.crm.objects.deal_splits.models.error_detail import ErrorDetail
from hubspot.crm.objects.deal_splits.models.public_deal_split_input import PublicDealSplitInput
from hubspot.crm.objects.deal_splits.models.public_deal_splits_batch_create_request import PublicDealSplitsBatchCreateRequest
from hubspot.crm.objects.deal_splits.models.public_deal_splits_create_request import PublicDealSplitsCreateRequest
from hubspot.crm.objects.deal_splits.models.public_object_id import PublicObjectId
from hubspot.crm.objects.deal_splits.models.simple_public_object import SimplePublicObject
from hubspot.crm.objects.deal_splits.models.standard_error import StandardError
from hubspot.crm.objects.deal_splits.models.value_with_timestamp import ValueWithTimestamp
