# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicFormSubmissionFilterCoalescingRefineBy(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "max_occurrences": "int",
        "type": "str",
        "min_occurrences": "int",
        "set_type": "str",
        "comparison": "str",
        "time_offset": "PublicTimeOffset",
        "upper_bound_offset": "PublicTimeOffset",
        "range_type": "str",
        "lower_bound_offset": "PublicTimeOffset",
        "timestamp": "int",
        "upper_timestamp": "int",
        "lower_timestamp": "int",
        "endpoint_behavior": "str",
        "include_objects_with_no_value_set": "bool",
        "property_parser": "str",
        "operation_type": "str",
        "time_point": "PublicTimePointOperationTimePoint",
        "operator": "str",
        "upper_bound_endpoint_behavior": "str",
        "upper_bound_time_point": "PublicTimePointOperationTimePoint",
        "lower_bound_endpoint_behavior": "str",
        "lower_bound_time_point": "PublicTimePointOperationTimePoint",
    }

    attribute_map = {
        "max_occurrences": "maxOccurrences",
        "type": "type",
        "min_occurrences": "minOccurrences",
        "set_type": "setType",
        "comparison": "comparison",
        "time_offset": "timeOffset",
        "upper_bound_offset": "upperBoundOffset",
        "range_type": "rangeType",
        "lower_bound_offset": "lowerBoundOffset",
        "timestamp": "timestamp",
        "upper_timestamp": "upperTimestamp",
        "lower_timestamp": "lowerTimestamp",
        "endpoint_behavior": "endpointBehavior",
        "include_objects_with_no_value_set": "includeObjectsWithNoValueSet",
        "property_parser": "propertyParser",
        "operation_type": "operationType",
        "time_point": "timePoint",
        "operator": "operator",
        "upper_bound_endpoint_behavior": "upperBoundEndpointBehavior",
        "upper_bound_time_point": "upperBoundTimePoint",
        "lower_bound_endpoint_behavior": "lowerBoundEndpointBehavior",
        "lower_bound_time_point": "lowerBoundTimePoint",
    }

    def __init__(
        self,
        max_occurrences=None,
        type="TIME_RANGED",
        min_occurrences=None,
        set_type=None,
        comparison=None,
        time_offset=None,
        upper_bound_offset=None,
        range_type=None,
        lower_bound_offset=None,
        timestamp=None,
        upper_timestamp=None,
        lower_timestamp=None,
        endpoint_behavior=None,
        include_objects_with_no_value_set=None,
        property_parser=None,
        operation_type=None,
        time_point=None,
        operator=None,
        upper_bound_endpoint_behavior=None,
        upper_bound_time_point=None,
        lower_bound_endpoint_behavior=None,
        lower_bound_time_point=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicFormSubmissionFilterCoalescingRefineBy - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._max_occurrences = None
        self._type = None
        self._min_occurrences = None
        self._set_type = None
        self._comparison = None
        self._time_offset = None
        self._upper_bound_offset = None
        self._range_type = None
        self._lower_bound_offset = None
        self._timestamp = None
        self._upper_timestamp = None
        self._lower_timestamp = None
        self._endpoint_behavior = None
        self._include_objects_with_no_value_set = None
        self._property_parser = None
        self._operation_type = None
        self._time_point = None
        self._operator = None
        self._upper_bound_endpoint_behavior = None
        self._upper_bound_time_point = None
        self._lower_bound_endpoint_behavior = None
        self._lower_bound_time_point = None
        self.discriminator = None

        if max_occurrences is not None:
            self.max_occurrences = max_occurrences
        self.type = type
        if min_occurrences is not None:
            self.min_occurrences = min_occurrences
        self.set_type = set_type
        self.comparison = comparison
        self.time_offset = time_offset
        self.upper_bound_offset = upper_bound_offset
        self.range_type = range_type
        self.lower_bound_offset = lower_bound_offset
        self.timestamp = timestamp
        self.upper_timestamp = upper_timestamp
        self.lower_timestamp = lower_timestamp
        if endpoint_behavior is not None:
            self.endpoint_behavior = endpoint_behavior
        self.include_objects_with_no_value_set = include_objects_with_no_value_set
        if property_parser is not None:
            self.property_parser = property_parser
        self.operation_type = operation_type
        self.time_point = time_point
        self.operator = operator
        if upper_bound_endpoint_behavior is not None:
            self.upper_bound_endpoint_behavior = upper_bound_endpoint_behavior
        self.upper_bound_time_point = upper_bound_time_point
        if lower_bound_endpoint_behavior is not None:
            self.lower_bound_endpoint_behavior = lower_bound_endpoint_behavior
        self.lower_bound_time_point = lower_bound_time_point

    @property
    def max_occurrences(self):
        """Gets the max_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The max_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._max_occurrences

    @max_occurrences.setter
    def max_occurrences(self, max_occurrences):
        """Sets the max_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param max_occurrences: The max_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type max_occurrences: int
        """

        self._max_occurrences = max_occurrences

    @property
    def type(self):
        """Gets the type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param type: The type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["TIME_RANGED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def min_occurrences(self):
        """Gets the min_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The min_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._min_occurrences

    @min_occurrences.setter
    def min_occurrences(self, min_occurrences):
        """Sets the min_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param min_occurrences: The min_occurrences of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type min_occurrences: int
        """

        self._min_occurrences = min_occurrences

    @property
    def set_type(self):
        """Gets the set_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The set_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._set_type

    @set_type.setter
    def set_type(self, set_type):
        """Sets the set_type of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param set_type: The set_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type set_type: str
        """
        if self.local_vars_configuration.client_side_validation and set_type is None:  # noqa: E501
            raise ValueError("Invalid value for `set_type`, must not be `None`")  # noqa: E501

        self._set_type = set_type

    @property
    def comparison(self):
        """Gets the comparison of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The comparison of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._comparison

    @comparison.setter
    def comparison(self, comparison):
        """Sets the comparison of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param comparison: The comparison of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type comparison: str
        """
        if self.local_vars_configuration.client_side_validation and comparison is None:  # noqa: E501
            raise ValueError("Invalid value for `comparison`, must not be `None`")  # noqa: E501

        self._comparison = comparison

    @property
    def time_offset(self):
        """Gets the time_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The time_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimeOffset
        """
        return self._time_offset

    @time_offset.setter
    def time_offset(self, time_offset):
        """Sets the time_offset of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param time_offset: The time_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type time_offset: PublicTimeOffset
        """
        if self.local_vars_configuration.client_side_validation and time_offset is None:  # noqa: E501
            raise ValueError("Invalid value for `time_offset`, must not be `None`")  # noqa: E501

        self._time_offset = time_offset

    @property
    def upper_bound_offset(self):
        """Gets the upper_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The upper_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimeOffset
        """
        return self._upper_bound_offset

    @upper_bound_offset.setter
    def upper_bound_offset(self, upper_bound_offset):
        """Sets the upper_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param upper_bound_offset: The upper_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type upper_bound_offset: PublicTimeOffset
        """
        if self.local_vars_configuration.client_side_validation and upper_bound_offset is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_bound_offset`, must not be `None`")  # noqa: E501

        self._upper_bound_offset = upper_bound_offset

    @property
    def range_type(self):
        """Gets the range_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The range_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._range_type

    @range_type.setter
    def range_type(self, range_type):
        """Sets the range_type of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param range_type: The range_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type range_type: str
        """
        if self.local_vars_configuration.client_side_validation and range_type is None:  # noqa: E501
            raise ValueError("Invalid value for `range_type`, must not be `None`")  # noqa: E501

        self._range_type = range_type

    @property
    def lower_bound_offset(self):
        """Gets the lower_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The lower_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimeOffset
        """
        return self._lower_bound_offset

    @lower_bound_offset.setter
    def lower_bound_offset(self, lower_bound_offset):
        """Sets the lower_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param lower_bound_offset: The lower_bound_offset of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type lower_bound_offset: PublicTimeOffset
        """
        if self.local_vars_configuration.client_side_validation and lower_bound_offset is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_bound_offset`, must not be `None`")  # noqa: E501

        self._lower_bound_offset = lower_bound_offset

    @property
    def timestamp(self):
        """Gets the timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param timestamp: The timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    @property
    def upper_timestamp(self):
        """Gets the upper_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The upper_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._upper_timestamp

    @upper_timestamp.setter
    def upper_timestamp(self, upper_timestamp):
        """Sets the upper_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param upper_timestamp: The upper_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type upper_timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and upper_timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_timestamp`, must not be `None`")  # noqa: E501

        self._upper_timestamp = upper_timestamp

    @property
    def lower_timestamp(self):
        """Gets the lower_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The lower_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._lower_timestamp

    @lower_timestamp.setter
    def lower_timestamp(self, lower_timestamp):
        """Sets the lower_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param lower_timestamp: The lower_timestamp of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type lower_timestamp: int
        """
        if self.local_vars_configuration.client_side_validation and lower_timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_timestamp`, must not be `None`")  # noqa: E501

        self._lower_timestamp = lower_timestamp

    @property
    def endpoint_behavior(self):
        """Gets the endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_behavior

    @endpoint_behavior.setter
    def endpoint_behavior(self, endpoint_behavior):
        """Sets the endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param endpoint_behavior: The endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type endpoint_behavior: str
        """

        self._endpoint_behavior = endpoint_behavior

    @property
    def include_objects_with_no_value_set(self):
        """Gets the include_objects_with_no_value_set of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The include_objects_with_no_value_set of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: bool
        """
        return self._include_objects_with_no_value_set

    @include_objects_with_no_value_set.setter
    def include_objects_with_no_value_set(self, include_objects_with_no_value_set):
        """Sets the include_objects_with_no_value_set of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param include_objects_with_no_value_set: The include_objects_with_no_value_set of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type include_objects_with_no_value_set: bool
        """
        if self.local_vars_configuration.client_side_validation and include_objects_with_no_value_set is None:  # noqa: E501
            raise ValueError("Invalid value for `include_objects_with_no_value_set`, must not be `None`")  # noqa: E501

        self._include_objects_with_no_value_set = include_objects_with_no_value_set

    @property
    def property_parser(self):
        """Gets the property_parser of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The property_parser of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._property_parser

    @property_parser.setter
    def property_parser(self, property_parser):
        """Sets the property_parser of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param property_parser: The property_parser of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type property_parser: str
        """

        self._property_parser = property_parser

    @property
    def operation_type(self):
        """Gets the operation_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The operation_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """Sets the operation_type of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param operation_type: The operation_type of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type operation_type: str
        """
        if self.local_vars_configuration.client_side_validation and operation_type is None:  # noqa: E501
            raise ValueError("Invalid value for `operation_type`, must not be `None`")  # noqa: E501

        self._operation_type = operation_type

    @property
    def time_point(self):
        """Gets the time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._time_point

    @time_point.setter
    def time_point(self, time_point):
        """Sets the time_point of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param time_point: The time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `time_point`, must not be `None`")  # noqa: E501

        self._time_point = time_point

    @property
    def operator(self):
        """Gets the operator of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The operator of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param operator: The operator of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    @property
    def upper_bound_endpoint_behavior(self):
        """Gets the upper_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The upper_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._upper_bound_endpoint_behavior

    @upper_bound_endpoint_behavior.setter
    def upper_bound_endpoint_behavior(self, upper_bound_endpoint_behavior):
        """Sets the upper_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param upper_bound_endpoint_behavior: The upper_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type upper_bound_endpoint_behavior: str
        """

        self._upper_bound_endpoint_behavior = upper_bound_endpoint_behavior

    @property
    def upper_bound_time_point(self):
        """Gets the upper_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The upper_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._upper_bound_time_point

    @upper_bound_time_point.setter
    def upper_bound_time_point(self, upper_bound_time_point):
        """Sets the upper_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param upper_bound_time_point: The upper_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type upper_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and upper_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_bound_time_point`, must not be `None`")  # noqa: E501

        self._upper_bound_time_point = upper_bound_time_point

    @property
    def lower_bound_endpoint_behavior(self):
        """Gets the lower_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The lower_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._lower_bound_endpoint_behavior

    @lower_bound_endpoint_behavior.setter
    def lower_bound_endpoint_behavior(self, lower_bound_endpoint_behavior):
        """Sets the lower_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param lower_bound_endpoint_behavior: The lower_bound_endpoint_behavior of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type lower_bound_endpoint_behavior: str
        """

        self._lower_bound_endpoint_behavior = lower_bound_endpoint_behavior

    @property
    def lower_bound_time_point(self):
        """Gets the lower_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501


        :return: The lower_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._lower_bound_time_point

    @lower_bound_time_point.setter
    def lower_bound_time_point(self, lower_bound_time_point):
        """Sets the lower_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.


        :param lower_bound_time_point: The lower_bound_time_point of this PublicFormSubmissionFilterCoalescingRefineBy.  # noqa: E501
        :type lower_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and lower_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_bound_time_point`, must not be `None`")  # noqa: E501

        self._lower_bound_time_point = lower_bound_time_point

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicFormSubmissionFilterCoalescingRefineBy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicFormSubmissionFilterCoalescingRefineBy):
            return True

        return self.to_dict() != other.to_dict()
