# coding: utf-8

# flake8: noqa

"""
    CRM Associations

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.associations.v4.api.basic_api import BasicApi
from hubspot.crm.associations.v4.api.batch_api import BatchApi
from hubspot.crm.associations.v4.api.report_api import ReportApi

# import ApiClient
from hubspot.crm.associations.v4.api_client import ApiClient
from hubspot.crm.associations.v4.configuration import Configuration
from hubspot.crm.associations.v4.exceptions import OpenApiException
from hubspot.crm.associations.v4.exceptions import ApiTypeError
from hubspot.crm.associations.v4.exceptions import ApiValueError
from hubspot.crm.associations.v4.exceptions import ApiKeyError
from hubspot.crm.associations.v4.exceptions import ApiAttributeError
from hubspot.crm.associations.v4.exceptions import ApiException

# import models into sdk package
from hubspot.crm.associations.v4.models.association_spec import AssociationSpec
from hubspot.crm.associations.v4.models.association_spec_with_label import AssociationSpecWithLabel
from hubspot.crm.associations.v4.models.batch_input_public_association_multi_archive import BatchInputPublicAssociationMultiArchive
from hubspot.crm.associations.v4.models.batch_input_public_association_multi_post import BatchInputPublicAssociationMultiPost
from hubspot.crm.associations.v4.models.batch_input_public_default_association_multi_post import BatchInputPublicDefaultAssociationMultiPost
from hubspot.crm.associations.v4.models.batch_input_public_fetch_associations_batch_request import BatchInputPublicFetchAssociationsBatchRequest
from hubspot.crm.associations.v4.models.batch_response_labels_between_object_pair import BatchResponseLabelsBetweenObjectPair
from hubspot.crm.associations.v4.models.batch_response_labels_between_object_pair_with_errors import BatchResponseLabelsBetweenObjectPairWithErrors
from hubspot.crm.associations.v4.models.batch_response_public_association_multi_with_label import BatchResponsePublicAssociationMultiWithLabel
from hubspot.crm.associations.v4.models.batch_response_public_association_multi_with_label_with_errors import BatchResponsePublicAssociationMultiWithLabelWithErrors
from hubspot.crm.associations.v4.models.batch_response_public_default_association import BatchResponsePublicDefaultAssociation
from hubspot.crm.associations.v4.models.collection_response_multi_associated_object_with_label_forward_paging import CollectionResponseMultiAssociatedObjectWithLabelForwardPaging
from hubspot.crm.associations.v4.models.date_time import DateTime
from hubspot.crm.associations.v4.models.error import Error
from hubspot.crm.associations.v4.models.error_detail import ErrorDetail
from hubspot.crm.associations.v4.models.forward_paging import ForwardPaging
from hubspot.crm.associations.v4.models.labels_between_object_pair import LabelsBetweenObjectPair
from hubspot.crm.associations.v4.models.multi_associated_object_with_label import MultiAssociatedObjectWithLabel
from hubspot.crm.associations.v4.models.next_page import NextPage
from hubspot.crm.associations.v4.models.paging import Paging
from hubspot.crm.associations.v4.models.previous_page import PreviousPage
from hubspot.crm.associations.v4.models.public_association_multi_archive import PublicAssociationMultiArchive
from hubspot.crm.associations.v4.models.public_association_multi_post import PublicAssociationMultiPost
from hubspot.crm.associations.v4.models.public_association_multi_with_label import PublicAssociationMultiWithLabel
from hubspot.crm.associations.v4.models.public_default_association import PublicDefaultAssociation
from hubspot.crm.associations.v4.models.public_default_association_multi_post import PublicDefaultAssociationMultiPost
from hubspot.crm.associations.v4.models.public_fetch_associations_batch_request import PublicFetchAssociationsBatchRequest
from hubspot.crm.associations.v4.models.public_object_id import PublicObjectId
from hubspot.crm.associations.v4.models.report_creation_response import ReportCreationResponse
from hubspot.crm.associations.v4.models.standard_error import StandardError
