# coding: utf-8

# flake8: noqa

"""
    Associations Schema

    Associations define the relationships between objects in HubSpot. These endpoints allow you to create, read, and remove associations.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.associations.schema.api.types_api import TypesApi

# import ApiClient
from hubspot.crm.associations.schema.api_client import ApiClient
from hubspot.crm.associations.schema.configuration import Configuration
from hubspot.crm.associations.schema.exceptions import OpenApiException
from hubspot.crm.associations.schema.exceptions import ApiTypeError
from hubspot.crm.associations.schema.exceptions import ApiValueError
from hubspot.crm.associations.schema.exceptions import ApiKeyError
from hubspot.crm.associations.schema.exceptions import ApiAttributeError
from hubspot.crm.associations.schema.exceptions import ApiException

# import models into sdk package
from hubspot.crm.associations.schema.models.collection_response_public_association_definition_no_paging import CollectionResponsePublicAssociationDefinitionNoPaging
from hubspot.crm.associations.schema.models.error import Error
from hubspot.crm.associations.schema.models.error_detail import ErrorDetail
from hubspot.crm.associations.schema.models.public_association_definition import PublicAssociationDefinition
