# coding: utf-8

# flake8: noqa
"""
    Video Conferencing Extension

    These APIs allow you to specify URLs that can be used to interact with a video conferencing application, to allow HubSpot to add video conference links to meeting requests with contacts.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.extensions.videoconferencing.models.error import Error
from hubspot.crm.extensions.videoconferencing.models.error_detail import ErrorDetail
from hubspot.crm.extensions.videoconferencing.models.external_settings import ExternalSettings
