# coding: utf-8

# flake8: noqa

"""
    Video Conferencing Extension

    These APIs allow you to specify URLs that can be used to interact with a video conferencing application, to allow HubSpot to add video conference links to meeting requests with contacts.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.extensions.videoconferencing.api.settings_api import SettingsApi

# import ApiClient
from hubspot.crm.extensions.videoconferencing.api_client import ApiClient
from hubspot.crm.extensions.videoconferencing.configuration import Configuration
from hubspot.crm.extensions.videoconferencing.exceptions import OpenApiException
from hubspot.crm.extensions.videoconferencing.exceptions import ApiTypeError
from hubspot.crm.extensions.videoconferencing.exceptions import ApiValueError
from hubspot.crm.extensions.videoconferencing.exceptions import ApiKeyError
from hubspot.crm.extensions.videoconferencing.exceptions import ApiAttributeError
from hubspot.crm.extensions.videoconferencing.exceptions import ApiException

# import models into sdk package
from hubspot.crm.extensions.videoconferencing.models.error import Error
from hubspot.crm.extensions.videoconferencing.models.error_detail import ErrorDetail
from hubspot.crm.extensions.videoconferencing.models.external_settings import ExternalSettings
