from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.crm.associations.v4.schema.api.definition_configurations_api import DefinitionConfigurationsApi
from hubspot.crm.associations.v4.schema.api.definitions_api import DefinitionsApi
