# coding: utf-8

# flake8: noqa
"""
    Authors

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.cms.blogs.authors.models.attach_to_lang_primary_request_v_next import AttachToLangPrimaryRequestVNext
from hubspot.cms.blogs.authors.models.batch_input_blog_author import BatchInputBlogAuthor
from hubspot.cms.blogs.authors.models.batch_input_json_node import BatchInputJsonNode
from hubspot.cms.blogs.authors.models.batch_input_string import BatchInputString
from hubspot.cms.blogs.authors.models.batch_response_blog_author import BatchResponseBlogAuthor
from hubspot.cms.blogs.authors.models.batch_response_blog_author_with_errors import BatchResponseBlogAuthorWithErrors
from hubspot.cms.blogs.authors.models.blog_author import BlogAuthor
from hubspot.cms.blogs.authors.models.blog_author_clone_request_v_next import BlogAuthorCloneRequestVNext
from hubspot.cms.blogs.authors.models.collection_response_with_total_blog_author_forward_paging import CollectionResponseWithTotalBlogAuthorForwardPaging
from hubspot.cms.blogs.authors.models.detach_from_lang_group_request_v_next import DetachFromLangGroupRequestVNext
from hubspot.cms.blogs.authors.models.error import Error
from hubspot.cms.blogs.authors.models.error_detail import ErrorDetail
from hubspot.cms.blogs.authors.models.forward_paging import ForwardPaging
from hubspot.cms.blogs.authors.models.next_page import NextPage
from hubspot.cms.blogs.authors.models.set_new_language_primary_request_v_next import SetNewLanguagePrimaryRequestVNext
from hubspot.cms.blogs.authors.models.standard_error import StandardError
from hubspot.cms.blogs.authors.models.update_languages_request_v_next import UpdateLanguagesRequestVNext
