# coding: utf-8

"""
    Webhooks Webhooks

    Provides a way for apps to subscribe to certain change events in HubSpot. Once configured, apps will receive event payloads containing details about the changes at a specified target URL. There can only be one target URL for receiving event notifications per app.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.webhooks.configuration import Configuration


class SettingsResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"created_at": "datetime", "throttling": "ThrottlingSettings", "target_url": "str", "updated_at": "datetime"}

    attribute_map = {"created_at": "createdAt", "throttling": "throttling", "target_url": "targetUrl", "updated_at": "updatedAt"}

    def __init__(self, created_at=None, throttling=None, target_url=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """SettingsResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._throttling = None
        self._target_url = None
        self._updated_at = None
        self.discriminator = None

        self.created_at = created_at
        self.throttling = throttling
        self.target_url = target_url
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this SettingsResponse.  # noqa: E501

        When this subscription was created. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :return: The created_at of this SettingsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SettingsResponse.

        When this subscription was created. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :param created_at: The created_at of this SettingsResponse.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def throttling(self):
        """Gets the throttling of this SettingsResponse.  # noqa: E501


        :return: The throttling of this SettingsResponse.  # noqa: E501
        :rtype: ThrottlingSettings
        """
        return self._throttling

    @throttling.setter
    def throttling(self, throttling):
        """Sets the throttling of this SettingsResponse.


        :param throttling: The throttling of this SettingsResponse.  # noqa: E501
        :type throttling: ThrottlingSettings
        """
        if self.local_vars_configuration.client_side_validation and throttling is None:  # noqa: E501
            raise ValueError("Invalid value for `throttling`, must not be `None`")  # noqa: E501

        self._throttling = throttling

    @property
    def target_url(self):
        """Gets the target_url of this SettingsResponse.  # noqa: E501

        A publicly available URL for HubSpot to call where event payloads will be delivered. See [link-so-some-doc](#) for details about the format of these event payloads.  # noqa: E501

        :return: The target_url of this SettingsResponse.  # noqa: E501
        :rtype: str
        """
        return self._target_url

    @target_url.setter
    def target_url(self, target_url):
        """Sets the target_url of this SettingsResponse.

        A publicly available URL for HubSpot to call where event payloads will be delivered. See [link-so-some-doc](#) for details about the format of these event payloads.  # noqa: E501

        :param target_url: The target_url of this SettingsResponse.  # noqa: E501
        :type target_url: str
        """
        if self.local_vars_configuration.client_side_validation and target_url is None:  # noqa: E501
            raise ValueError("Invalid value for `target_url`, must not be `None`")  # noqa: E501

        self._target_url = target_url

    @property
    def updated_at(self):
        """Gets the updated_at of this SettingsResponse.  # noqa: E501

        When this subscription was last updated. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :return: The updated_at of this SettingsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SettingsResponse.

        When this subscription was last updated. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :param updated_at: The updated_at of this SettingsResponse.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SettingsResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SettingsResponse):
            return True

        return self.to_dict() != other.to_dict()
