# coding: utf-8

# flake8: noqa

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.files.api.files_api import FilesApi
from hubspot.files.api.folders_api import FoldersApi

# import ApiClient
from hubspot.files.api_client import ApiClient
from hubspot.files.configuration import Configuration
from hubspot.files.exceptions import OpenApiException
from hubspot.files.exceptions import ApiTypeError
from hubspot.files.exceptions import ApiValueError
from hubspot.files.exceptions import ApiKeyError
from hubspot.files.exceptions import ApiAttributeError
from hubspot.files.exceptions import ApiException

# import models into sdk package
from hubspot.files.models.collection_response_file import CollectionResponseFile
from hubspot.files.models.collection_response_folder import CollectionResponseFolder
from hubspot.files.models.error import Error
from hubspot.files.models.error_detail import ErrorDetail
from hubspot.files.models.file import File
from hubspot.files.models.file_action_response import FileActionResponse
from hubspot.files.models.file_stat import FileStat
from hubspot.files.models.file_update_input import FileUpdateInput
from hubspot.files.models.folder import Folder
from hubspot.files.models.folder_action_response import FolderActionResponse
from hubspot.files.models.folder_input import FolderInput
from hubspot.files.models.folder_update_input import FolderUpdateInput
from hubspot.files.models.folder_update_input_with_id import FolderUpdateInputWithId
from hubspot.files.models.folder_update_task_locator import FolderUpdateTaskLocator
from hubspot.files.models.import_from_url_input import ImportFromUrlInput
from hubspot.files.models.import_from_url_task_locator import ImportFromUrlTaskLocator
from hubspot.files.models.next_page import NextPage
from hubspot.files.models.paging import Paging
from hubspot.files.models.previous_page import PreviousPage
from hubspot.files.models.signed_url import SignedUrl
from hubspot.files.models.standard_error import StandardError
