# coding: utf-8

"""
    Imports

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.imports.configuration import Configuration


class PublicImportResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "import_template": "ImportTemplate",
        "created_at": "datetime",
        "metadata": "PublicImportMetadata",
        "import_request_json": "object",
        "import_source": "str",
        "import_name": "str",
        "state": "str",
        "id": "str",
        "opt_out_import": "bool",
        "mapped_object_type_ids": "list[str]",
        "updated_at": "datetime",
    }

    attribute_map = {
        "import_template": "importTemplate",
        "created_at": "createdAt",
        "metadata": "metadata",
        "import_request_json": "importRequestJson",
        "import_source": "importSource",
        "import_name": "importName",
        "state": "state",
        "id": "id",
        "opt_out_import": "optOutImport",
        "mapped_object_type_ids": "mappedObjectTypeIds",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        import_template=None,
        created_at=None,
        metadata=None,
        import_request_json=None,
        import_source=None,
        import_name=None,
        state=None,
        id=None,
        opt_out_import=None,
        mapped_object_type_ids=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicImportResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._import_template = None
        self._created_at = None
        self._metadata = None
        self._import_request_json = None
        self._import_source = None
        self._import_name = None
        self._state = None
        self._id = None
        self._opt_out_import = None
        self._mapped_object_type_ids = None
        self._updated_at = None
        self.discriminator = None

        if import_template is not None:
            self.import_template = import_template
        self.created_at = created_at
        self.metadata = metadata
        if import_request_json is not None:
            self.import_request_json = import_request_json
        if import_source is not None:
            self.import_source = import_source
        if import_name is not None:
            self.import_name = import_name
        self.state = state
        self.id = id
        self.opt_out_import = opt_out_import
        self.mapped_object_type_ids = mapped_object_type_ids
        self.updated_at = updated_at

    @property
    def import_template(self):
        """Gets the import_template of this PublicImportResponse.  # noqa: E501


        :return: The import_template of this PublicImportResponse.  # noqa: E501
        :rtype: ImportTemplate
        """
        return self._import_template

    @import_template.setter
    def import_template(self, import_template):
        """Sets the import_template of this PublicImportResponse.


        :param import_template: The import_template of this PublicImportResponse.  # noqa: E501
        :type import_template: ImportTemplate
        """

        self._import_template = import_template

    @property
    def created_at(self):
        """Gets the created_at of this PublicImportResponse.  # noqa: E501


        :return: The created_at of this PublicImportResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PublicImportResponse.


        :param created_at: The created_at of this PublicImportResponse.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def metadata(self):
        """Gets the metadata of this PublicImportResponse.  # noqa: E501


        :return: The metadata of this PublicImportResponse.  # noqa: E501
        :rtype: PublicImportMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this PublicImportResponse.


        :param metadata: The metadata of this PublicImportResponse.  # noqa: E501
        :type metadata: PublicImportMetadata
        """
        if self.local_vars_configuration.client_side_validation and metadata is None:  # noqa: E501
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def import_request_json(self):
        """Gets the import_request_json of this PublicImportResponse.  # noqa: E501


        :return: The import_request_json of this PublicImportResponse.  # noqa: E501
        :rtype: object
        """
        return self._import_request_json

    @import_request_json.setter
    def import_request_json(self, import_request_json):
        """Sets the import_request_json of this PublicImportResponse.


        :param import_request_json: The import_request_json of this PublicImportResponse.  # noqa: E501
        :type import_request_json: object
        """

        self._import_request_json = import_request_json

    @property
    def import_source(self):
        """Gets the import_source of this PublicImportResponse.  # noqa: E501


        :return: The import_source of this PublicImportResponse.  # noqa: E501
        :rtype: str
        """
        return self._import_source

    @import_source.setter
    def import_source(self, import_source):
        """Sets the import_source of this PublicImportResponse.


        :param import_source: The import_source of this PublicImportResponse.  # noqa: E501
        :type import_source: str
        """
        allowed_values = ["API", "CRM_UI", "IMPORT", "MOBILE_ANDROID", "MOBILE_IOS", "SALESFORCE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and import_source not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `import_source` ({0}), must be one of {1}".format(import_source, allowed_values))  # noqa: E501

        self._import_source = import_source

    @property
    def import_name(self):
        """Gets the import_name of this PublicImportResponse.  # noqa: E501


        :return: The import_name of this PublicImportResponse.  # noqa: E501
        :rtype: str
        """
        return self._import_name

    @import_name.setter
    def import_name(self, import_name):
        """Sets the import_name of this PublicImportResponse.


        :param import_name: The import_name of this PublicImportResponse.  # noqa: E501
        :type import_name: str
        """

        self._import_name = import_name

    @property
    def state(self):
        """Gets the state of this PublicImportResponse.  # noqa: E501

        The status of the import.  # noqa: E501

        :return: The state of this PublicImportResponse.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PublicImportResponse.

        The status of the import.  # noqa: E501

        :param state: The state of this PublicImportResponse.  # noqa: E501
        :type state: str
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501
        allowed_values = ["STARTED", "PROCESSING", "DONE", "FAILED", "CANCELED", "DEFERRED", "REVERTED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `state` ({0}), must be one of {1}".format(state, allowed_values))  # noqa: E501

        self._state = state

    @property
    def id(self):
        """Gets the id of this PublicImportResponse.  # noqa: E501


        :return: The id of this PublicImportResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PublicImportResponse.


        :param id: The id of this PublicImportResponse.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def opt_out_import(self):
        """Gets the opt_out_import of this PublicImportResponse.  # noqa: E501

        Whether or not the import is a list of people disqualified from receiving emails.  # noqa: E501

        :return: The opt_out_import of this PublicImportResponse.  # noqa: E501
        :rtype: bool
        """
        return self._opt_out_import

    @opt_out_import.setter
    def opt_out_import(self, opt_out_import):
        """Sets the opt_out_import of this PublicImportResponse.

        Whether or not the import is a list of people disqualified from receiving emails.  # noqa: E501

        :param opt_out_import: The opt_out_import of this PublicImportResponse.  # noqa: E501
        :type opt_out_import: bool
        """
        if self.local_vars_configuration.client_side_validation and opt_out_import is None:  # noqa: E501
            raise ValueError("Invalid value for `opt_out_import`, must not be `None`")  # noqa: E501

        self._opt_out_import = opt_out_import

    @property
    def mapped_object_type_ids(self):
        """Gets the mapped_object_type_ids of this PublicImportResponse.  # noqa: E501


        :return: The mapped_object_type_ids of this PublicImportResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._mapped_object_type_ids

    @mapped_object_type_ids.setter
    def mapped_object_type_ids(self, mapped_object_type_ids):
        """Sets the mapped_object_type_ids of this PublicImportResponse.


        :param mapped_object_type_ids: The mapped_object_type_ids of this PublicImportResponse.  # noqa: E501
        :type mapped_object_type_ids: list[str]
        """
        if self.local_vars_configuration.client_side_validation and mapped_object_type_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `mapped_object_type_ids`, must not be `None`")  # noqa: E501

        self._mapped_object_type_ids = mapped_object_type_ids

    @property
    def updated_at(self):
        """Gets the updated_at of this PublicImportResponse.  # noqa: E501


        :return: The updated_at of this PublicImportResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PublicImportResponse.


        :param updated_at: The updated_at of this PublicImportResponse.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicImportResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicImportResponse):
            return True

        return self.to_dict() != other.to_dict()
