# coding: utf-8

"""
    Imports

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.imports.configuration import Configuration


class ImportRowCore(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"row_data": "list[str]", "contains_encrypted_properties": "bool", "line_number": "int", "page_name": "str", "file_id": "int"}

    attribute_map = {"row_data": "rowData", "contains_encrypted_properties": "containsEncryptedProperties", "line_number": "lineNumber", "page_name": "pageName", "file_id": "fileId"}

    def __init__(self, row_data=None, contains_encrypted_properties=None, line_number=None, page_name=None, file_id=None, local_vars_configuration=None):  # noqa: E501
        """ImportRowCore - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._row_data = None
        self._contains_encrypted_properties = None
        self._line_number = None
        self._page_name = None
        self._file_id = None
        self.discriminator = None

        self.row_data = row_data
        self.contains_encrypted_properties = contains_encrypted_properties
        self.line_number = line_number
        if page_name is not None:
            self.page_name = page_name
        self.file_id = file_id

    @property
    def row_data(self):
        """Gets the row_data of this ImportRowCore.  # noqa: E501


        :return: The row_data of this ImportRowCore.  # noqa: E501
        :rtype: list[str]
        """
        return self._row_data

    @row_data.setter
    def row_data(self, row_data):
        """Sets the row_data of this ImportRowCore.


        :param row_data: The row_data of this ImportRowCore.  # noqa: E501
        :type row_data: list[str]
        """
        if self.local_vars_configuration.client_side_validation and row_data is None:  # noqa: E501
            raise ValueError("Invalid value for `row_data`, must not be `None`")  # noqa: E501

        self._row_data = row_data

    @property
    def contains_encrypted_properties(self):
        """Gets the contains_encrypted_properties of this ImportRowCore.  # noqa: E501


        :return: The contains_encrypted_properties of this ImportRowCore.  # noqa: E501
        :rtype: bool
        """
        return self._contains_encrypted_properties

    @contains_encrypted_properties.setter
    def contains_encrypted_properties(self, contains_encrypted_properties):
        """Sets the contains_encrypted_properties of this ImportRowCore.


        :param contains_encrypted_properties: The contains_encrypted_properties of this ImportRowCore.  # noqa: E501
        :type contains_encrypted_properties: bool
        """
        if self.local_vars_configuration.client_side_validation and contains_encrypted_properties is None:  # noqa: E501
            raise ValueError("Invalid value for `contains_encrypted_properties`, must not be `None`")  # noqa: E501

        self._contains_encrypted_properties = contains_encrypted_properties

    @property
    def line_number(self):
        """Gets the line_number of this ImportRowCore.  # noqa: E501


        :return: The line_number of this ImportRowCore.  # noqa: E501
        :rtype: int
        """
        return self._line_number

    @line_number.setter
    def line_number(self, line_number):
        """Sets the line_number of this ImportRowCore.


        :param line_number: The line_number of this ImportRowCore.  # noqa: E501
        :type line_number: int
        """
        if self.local_vars_configuration.client_side_validation and line_number is None:  # noqa: E501
            raise ValueError("Invalid value for `line_number`, must not be `None`")  # noqa: E501

        self._line_number = line_number

    @property
    def page_name(self):
        """Gets the page_name of this ImportRowCore.  # noqa: E501


        :return: The page_name of this ImportRowCore.  # noqa: E501
        :rtype: str
        """
        return self._page_name

    @page_name.setter
    def page_name(self, page_name):
        """Sets the page_name of this ImportRowCore.


        :param page_name: The page_name of this ImportRowCore.  # noqa: E501
        :type page_name: str
        """

        self._page_name = page_name

    @property
    def file_id(self):
        """Gets the file_id of this ImportRowCore.  # noqa: E501


        :return: The file_id of this ImportRowCore.  # noqa: E501
        :rtype: int
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this ImportRowCore.


        :param file_id: The file_id of this ImportRowCore.  # noqa: E501
        :type file_id: int
        """
        if self.local_vars_configuration.client_side_validation and file_id is None:  # noqa: E501
            raise ValueError("Invalid value for `file_id`, must not be `None`")  # noqa: E501

        self._file_id = file_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImportRowCore):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImportRowCore):
            return True

        return self.to_dict() != other.to_dict()
