# coding: utf-8

"""
    Conversations Custom Channels

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from hubspot.conversations.custom_channels.models.public_client import PublicClient
from hubspot.conversations.custom_channels.models.public_conversations_message_attachments_inner import PublicConversationsMessageAttachmentsInner
from hubspot.conversations.custom_channels.models.public_message_status import PublicMessageStatus
from hubspot.conversations.custom_channels.models.public_recipient import PublicRecipient
from hubspot.conversations.custom_channels.models.public_sender import PublicSender
from typing import Optional, Set
from typing_extensions import Self

class PublicConversationsMessage(BaseModel):
    """
    PublicConversationsMessage
    """ # noqa: E501
    attachments: List[PublicConversationsMessageAttachmentsInner]
    subject: Optional[StrictStr] = None
    conversations_thread_id: StrictStr = Field(alias="conversationsThreadId")
    type: StrictStr
    rich_text: Optional[StrictStr] = Field(default=None, alias="richText")
    in_reply_to_id: Optional[StrictStr] = Field(default=None, alias="inReplyToId")
    created_at: datetime = Field(alias="createdAt")
    archived: StrictBool
    created_by: StrictStr = Field(alias="createdBy")
    recipients: List[PublicRecipient]
    truncation_status: StrictStr = Field(alias="truncationStatus")
    client: PublicClient
    id: StrictStr
    text: StrictStr
    channel_account_id: StrictStr = Field(alias="channelAccountId")
    senders: List[PublicSender]
    channel_id: StrictStr = Field(alias="channelId")
    updated_at: Optional[datetime] = Field(default=None, alias="updatedAt")
    status: Optional[PublicMessageStatus] = None
    direction: StrictStr
    __properties: ClassVar[List[str]] = ["attachments", "subject", "conversationsThreadId", "type", "richText", "inReplyToId", "createdAt", "archived", "createdBy", "recipients", "truncationStatus", "client", "id", "text", "channelAccountId", "senders", "channelId", "updatedAt", "status", "direction"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['MESSAGE']):
            raise ValueError("must be one of enum values ('MESSAGE')")
        return value

    @field_validator('truncation_status')
    def truncation_status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['NOT_TRUNCATED', 'TRUNCATED_TO_MOST_RECENT_REPLY', 'TRUNCATED']):
            raise ValueError("must be one of enum values ('NOT_TRUNCATED', 'TRUNCATED_TO_MOST_RECENT_REPLY', 'TRUNCATED')")
        return value

    @field_validator('direction')
    def direction_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['INCOMING', 'OUTGOING']):
            raise ValueError("must be one of enum values ('INCOMING', 'OUTGOING')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PublicConversationsMessage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in recipients (list)
        _items = []
        if self.recipients:
            for _item_recipients in self.recipients:
                if _item_recipients:
                    _items.append(_item_recipients.to_dict())
            _dict['recipients'] = _items
        # override the default output from pydantic by calling `to_dict()` of client
        if self.client:
            _dict['client'] = self.client.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in senders (list)
        _items = []
        if self.senders:
            for _item_senders in self.senders:
                if _item_senders:
                    _items.append(_item_senders.to_dict())
            _dict['senders'] = _items
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PublicConversationsMessage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "attachments": [PublicConversationsMessageAttachmentsInner.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None,
            "subject": obj.get("subject"),
            "conversationsThreadId": obj.get("conversationsThreadId"),
            "type": obj.get("type") if obj.get("type") is not None else 'MESSAGE',
            "richText": obj.get("richText"),
            "inReplyToId": obj.get("inReplyToId"),
            "createdAt": obj.get("createdAt"),
            "archived": obj.get("archived"),
            "createdBy": obj.get("createdBy"),
            "recipients": [PublicRecipient.from_dict(_item) for _item in obj["recipients"]] if obj.get("recipients") is not None else None,
            "truncationStatus": obj.get("truncationStatus"),
            "client": PublicClient.from_dict(obj["client"]) if obj.get("client") is not None else None,
            "id": obj.get("id"),
            "text": obj.get("text"),
            "channelAccountId": obj.get("channelAccountId"),
            "senders": [PublicSender.from_dict(_item) for _item in obj["senders"]] if obj.get("senders") is not None else None,
            "channelId": obj.get("channelId"),
            "updatedAt": obj.get("updatedAt"),
            "status": PublicMessageStatus.from_dict(obj["status"]) if obj.get("status") is not None else None,
            "direction": obj.get("direction")
        })
        return _obj


