# coding: utf-8

"""
    Automation Actions V4

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.automation.actions.configuration import Configuration


class PublicActionLabels(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "input_field_descriptions": "dict[str, str]",
        "app_display_name": "str",
        "output_field_labels": "dict[str, str]",
        "input_field_option_labels": "dict[str, dict[str, str]]",
        "action_description": "str",
        "execution_rules": "dict[str, str]",
        "input_field_labels": "dict[str, str]",
        "action_name": "str",
        "action_card_content": "str",
    }

    attribute_map = {
        "input_field_descriptions": "inputFieldDescriptions",
        "app_display_name": "appDisplayName",
        "output_field_labels": "outputFieldLabels",
        "input_field_option_labels": "inputFieldOptionLabels",
        "action_description": "actionDescription",
        "execution_rules": "executionRules",
        "input_field_labels": "inputFieldLabels",
        "action_name": "actionName",
        "action_card_content": "actionCardContent",
    }

    def __init__(
        self,
        input_field_descriptions=None,
        app_display_name=None,
        output_field_labels=None,
        input_field_option_labels=None,
        action_description=None,
        execution_rules=None,
        input_field_labels=None,
        action_name=None,
        action_card_content=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicActionLabels - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._input_field_descriptions = None
        self._app_display_name = None
        self._output_field_labels = None
        self._input_field_option_labels = None
        self._action_description = None
        self._execution_rules = None
        self._input_field_labels = None
        self._action_name = None
        self._action_card_content = None
        self.discriminator = None

        if input_field_descriptions is not None:
            self.input_field_descriptions = input_field_descriptions
        if app_display_name is not None:
            self.app_display_name = app_display_name
        if output_field_labels is not None:
            self.output_field_labels = output_field_labels
        if input_field_option_labels is not None:
            self.input_field_option_labels = input_field_option_labels
        if action_description is not None:
            self.action_description = action_description
        if execution_rules is not None:
            self.execution_rules = execution_rules
        if input_field_labels is not None:
            self.input_field_labels = input_field_labels
        self.action_name = action_name
        if action_card_content is not None:
            self.action_card_content = action_card_content

    @property
    def input_field_descriptions(self):
        """Gets the input_field_descriptions of this PublicActionLabels.  # noqa: E501


        :return: The input_field_descriptions of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._input_field_descriptions

    @input_field_descriptions.setter
    def input_field_descriptions(self, input_field_descriptions):
        """Sets the input_field_descriptions of this PublicActionLabels.


        :param input_field_descriptions: The input_field_descriptions of this PublicActionLabels.  # noqa: E501
        :type input_field_descriptions: dict[str, str]
        """

        self._input_field_descriptions = input_field_descriptions

    @property
    def app_display_name(self):
        """Gets the app_display_name of this PublicActionLabels.  # noqa: E501


        :return: The app_display_name of this PublicActionLabels.  # noqa: E501
        :rtype: str
        """
        return self._app_display_name

    @app_display_name.setter
    def app_display_name(self, app_display_name):
        """Sets the app_display_name of this PublicActionLabels.


        :param app_display_name: The app_display_name of this PublicActionLabels.  # noqa: E501
        :type app_display_name: str
        """

        self._app_display_name = app_display_name

    @property
    def output_field_labels(self):
        """Gets the output_field_labels of this PublicActionLabels.  # noqa: E501


        :return: The output_field_labels of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._output_field_labels

    @output_field_labels.setter
    def output_field_labels(self, output_field_labels):
        """Sets the output_field_labels of this PublicActionLabels.


        :param output_field_labels: The output_field_labels of this PublicActionLabels.  # noqa: E501
        :type output_field_labels: dict[str, str]
        """

        self._output_field_labels = output_field_labels

    @property
    def input_field_option_labels(self):
        """Gets the input_field_option_labels of this PublicActionLabels.  # noqa: E501


        :return: The input_field_option_labels of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, dict[str, str]]
        """
        return self._input_field_option_labels

    @input_field_option_labels.setter
    def input_field_option_labels(self, input_field_option_labels):
        """Sets the input_field_option_labels of this PublicActionLabels.


        :param input_field_option_labels: The input_field_option_labels of this PublicActionLabels.  # noqa: E501
        :type input_field_option_labels: dict[str, dict[str, str]]
        """

        self._input_field_option_labels = input_field_option_labels

    @property
    def action_description(self):
        """Gets the action_description of this PublicActionLabels.  # noqa: E501


        :return: The action_description of this PublicActionLabels.  # noqa: E501
        :rtype: str
        """
        return self._action_description

    @action_description.setter
    def action_description(self, action_description):
        """Sets the action_description of this PublicActionLabels.


        :param action_description: The action_description of this PublicActionLabels.  # noqa: E501
        :type action_description: str
        """

        self._action_description = action_description

    @property
    def execution_rules(self):
        """Gets the execution_rules of this PublicActionLabels.  # noqa: E501


        :return: The execution_rules of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._execution_rules

    @execution_rules.setter
    def execution_rules(self, execution_rules):
        """Sets the execution_rules of this PublicActionLabels.


        :param execution_rules: The execution_rules of this PublicActionLabels.  # noqa: E501
        :type execution_rules: dict[str, str]
        """

        self._execution_rules = execution_rules

    @property
    def input_field_labels(self):
        """Gets the input_field_labels of this PublicActionLabels.  # noqa: E501


        :return: The input_field_labels of this PublicActionLabels.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._input_field_labels

    @input_field_labels.setter
    def input_field_labels(self, input_field_labels):
        """Sets the input_field_labels of this PublicActionLabels.


        :param input_field_labels: The input_field_labels of this PublicActionLabels.  # noqa: E501
        :type input_field_labels: dict[str, str]
        """

        self._input_field_labels = input_field_labels

    @property
    def action_name(self):
        """Gets the action_name of this PublicActionLabels.  # noqa: E501


        :return: The action_name of this PublicActionLabels.  # noqa: E501
        :rtype: str
        """
        return self._action_name

    @action_name.setter
    def action_name(self, action_name):
        """Sets the action_name of this PublicActionLabels.


        :param action_name: The action_name of this PublicActionLabels.  # noqa: E501
        :type action_name: str
        """
        if self.local_vars_configuration.client_side_validation and action_name is None:  # noqa: E501
            raise ValueError("Invalid value for `action_name`, must not be `None`")  # noqa: E501

        self._action_name = action_name

    @property
    def action_card_content(self):
        """Gets the action_card_content of this PublicActionLabels.  # noqa: E501


        :return: The action_card_content of this PublicActionLabels.  # noqa: E501
        :rtype: str
        """
        return self._action_card_content

    @action_card_content.setter
    def action_card_content(self, action_card_content):
        """Sets the action_card_content of this PublicActionLabels.


        :param action_card_content: The action_card_content of this PublicActionLabels.  # noqa: E501
        :type action_card_content: str
        """

        self._action_card_content = action_card_content

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicActionLabels):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicActionLabels):
            return True

        return self.to_dict() != other.to_dict()
