# coding: utf-8

# flake8: noqa
"""
    CRM Calling Extensions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.extensions.calling.models.channel_connection_settings_patch_request import ChannelConnectionSettingsPatchRequest
from hubspot.crm.extensions.calling.models.channel_connection_settings_request import ChannelConnectionSettingsRequest
from hubspot.crm.extensions.calling.models.channel_connection_settings_response import ChannelConnectionSettingsResponse
from hubspot.crm.extensions.calling.models.error import Error
from hubspot.crm.extensions.calling.models.error_detail import ErrorDetail
from hubspot.crm.extensions.calling.models.mark_recording_as_ready_request import MarkRecordingAsReadyRequest
from hubspot.crm.extensions.calling.models.recording_settings_patch_request import RecordingSettingsPatchRequest
from hubspot.crm.extensions.calling.models.recording_settings_request import RecordingSettingsRequest
from hubspot.crm.extensions.calling.models.recording_settings_response import RecordingSettingsResponse
from hubspot.crm.extensions.calling.models.settings_patch_request import SettingsPatchRequest
from hubspot.crm.extensions.calling.models.settings_request import SettingsRequest
from hubspot.crm.extensions.calling.models.settings_response import SettingsResponse
