# coding: utf-8

# flake8: noqa

"""
    CRM Associations Schema

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.associations.v4.schema.api.definition_configurations_api import DefinitionConfigurationsApi
from hubspot.crm.associations.v4.schema.api.definitions_api import DefinitionsApi

# import ApiClient
from hubspot.crm.associations.v4.schema.api_client import ApiClient
from hubspot.crm.associations.v4.schema.configuration import Configuration
from hubspot.crm.associations.v4.schema.exceptions import OpenApiException
from hubspot.crm.associations.v4.schema.exceptions import ApiTypeError
from hubspot.crm.associations.v4.schema.exceptions import ApiValueError
from hubspot.crm.associations.v4.schema.exceptions import ApiKeyError
from hubspot.crm.associations.v4.schema.exceptions import ApiAttributeError
from hubspot.crm.associations.v4.schema.exceptions import ApiException

# import models into sdk package
from hubspot.crm.associations.v4.schema.models.association_spec_with_label import AssociationSpecWithLabel
from hubspot.crm.associations.v4.schema.models.batch_input_public_association_definition_configuration_create_request import BatchInputPublicAssociationDefinitionConfigurationCreateRequest
from hubspot.crm.associations.v4.schema.models.batch_input_public_association_definition_configuration_update_request import BatchInputPublicAssociationDefinitionConfigurationUpdateRequest
from hubspot.crm.associations.v4.schema.models.batch_input_public_association_spec import BatchInputPublicAssociationSpec
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_configuration_update_result import BatchResponsePublicAssociationDefinitionConfigurationUpdateResult
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_configuration_update_result_with_errors import (
    BatchResponsePublicAssociationDefinitionConfigurationUpdateResultWithErrors,
)
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_user_configuration import BatchResponsePublicAssociationDefinitionUserConfiguration
from hubspot.crm.associations.v4.schema.models.batch_response_public_association_definition_user_configuration_with_errors import BatchResponsePublicAssociationDefinitionUserConfigurationWithErrors
from hubspot.crm.associations.v4.schema.models.collection_response_association_spec_with_label_no_paging import CollectionResponseAssociationSpecWithLabelNoPaging
from hubspot.crm.associations.v4.schema.models.collection_response_public_association_definition_user_configuration_no_paging import (
    CollectionResponsePublicAssociationDefinitionUserConfigurationNoPaging,
)
from hubspot.crm.associations.v4.schema.models.error import Error
from hubspot.crm.associations.v4.schema.models.error_detail import ErrorDetail
from hubspot.crm.associations.v4.schema.models.public_association_definition_configuration_create_request import PublicAssociationDefinitionConfigurationCreateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_configuration_update_request import PublicAssociationDefinitionConfigurationUpdateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_configuration_update_result import PublicAssociationDefinitionConfigurationUpdateResult
from hubspot.crm.associations.v4.schema.models.public_association_definition_create_request import PublicAssociationDefinitionCreateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_update_request import PublicAssociationDefinitionUpdateRequest
from hubspot.crm.associations.v4.schema.models.public_association_definition_user_configuration import PublicAssociationDefinitionUserConfiguration
from hubspot.crm.associations.v4.schema.models.public_association_spec import PublicAssociationSpec
from hubspot.crm.associations.v4.schema.models.standard_error import StandardError
