# coding: utf-8

# flake8: noqa

"""
    CRM Calling Extensions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.extensions.calling.api.channel_connection_settings_api import ChannelConnectionSettingsApi
from hubspot.crm.extensions.calling.api.recording_settings_api import RecordingSettingsApi
from hubspot.crm.extensions.calling.api.settings_api import SettingsApi

# import ApiClient
from hubspot.crm.extensions.calling.api_client import ApiClient
from hubspot.crm.extensions.calling.configuration import Configuration
from hubspot.crm.extensions.calling.exceptions import OpenApiException
from hubspot.crm.extensions.calling.exceptions import ApiTypeError
from hubspot.crm.extensions.calling.exceptions import ApiValueError
from hubspot.crm.extensions.calling.exceptions import ApiKeyError
from hubspot.crm.extensions.calling.exceptions import ApiAttributeError
from hubspot.crm.extensions.calling.exceptions import ApiException

# import models into sdk package
from hubspot.crm.extensions.calling.models.channel_connection_settings_patch_request import ChannelConnectionSettingsPatchRequest
from hubspot.crm.extensions.calling.models.channel_connection_settings_request import ChannelConnectionSettingsRequest
from hubspot.crm.extensions.calling.models.channel_connection_settings_response import ChannelConnectionSettingsResponse
from hubspot.crm.extensions.calling.models.error import Error
from hubspot.crm.extensions.calling.models.error_detail import ErrorDetail
from hubspot.crm.extensions.calling.models.mark_recording_as_ready_request import MarkRecordingAsReadyRequest
from hubspot.crm.extensions.calling.models.recording_settings_patch_request import RecordingSettingsPatchRequest
from hubspot.crm.extensions.calling.models.recording_settings_request import RecordingSettingsRequest
from hubspot.crm.extensions.calling.models.recording_settings_response import RecordingSettingsResponse
from hubspot.crm.extensions.calling.models.settings_patch_request import SettingsPatchRequest
from hubspot.crm.extensions.calling.models.settings_request import SettingsRequest
from hubspot.crm.extensions.calling.models.settings_response import SettingsResponse
