class AssociationType:
    PRIMARY_CONTACT_TO_COMPANY = 1
    PRIMARY_COMPANY_TO_CONTACT = 2
    DEAL_TO_CONTACT = 3
    CONTACT_TO_DEAL = 4
    PRIMARY_DEAL_TO_COMPANY = 5
    PRIMARY_COMPANY_TO_DEAL = 6
    CONTACT_TO_TICKET = 15
    TICKET_TO_CONTACT = 16
    DEAL_TO_LINE_ITEM = 19
    LINE_ITEM_TO_DEAL = 20
    PRIMARY_COMPANY_TO_TICKET = 25
    PRIMARY_TICKET_TO_COMPANY = 26
    DEAL_TO_TICKET = 27
    TICKET_TO_DEAL = 28
    DEAL_TO_QUOTE = 63
    QUOTE_TO_DEAL = 64
    QUOTE_TO_LINE_ITEM = 67
    LINE_ITEM_TO_QUOTE = 68
    QUOTE_TO_CONTACT = 69
    CONTACT_TO_QUOTE = 70
    QUOTE_TO_COMPANY = 71
    COMPANY_TO_QUOTE = 72
    CONTACT_TO_FEEDBACK_SUBMISSION = 97
    FEEDBACK_SUBMISSION_TO_CONTACT = 98
    TICKET_TO_FEEDBACK_SUBMISSION = 99
    FEEDBACK_SUBMISSION_TO_TICKET = 100
    COMPANY_TO_CALL = 181
    CALL_TO_COMPANY = 182
    COMPANY_TO_EMAIL = 185
    EMAIL_TO_COMPANY = 186
    COMPANY_TO_MEETING = 187
    MEETING_TO_COMPANY = 188
    COMPANY_TO_NOTE = 189
    NOTE_TO_COMPANY = 190
    COMPANY_TO_TASK = 191
    TASK_TO_COMPANY = 192
    CONTACT_TO_CALL = 193
    CALL_TO_CONTACT = 194
    CONTACT_TO_EMAIL = 197
    EMAIL_TO_CONTACT = 198
    CONTACT_TO_MEETING = 199
    MEETING_TO_CONTACT = 200
    CONTACT_TO_NOTE = 201
    NOTE_TO_CONTACT = 202
    CONTACT_TO_TASK = 203
    TASK_TO_CONTACT = 204
    DEAL_TO_CALL = 205
    CALL_TO_DEAL = 206
    DEAL_TO_EMAIL = 209
    EMAIL_TO_DEAL = 210
    DEAL_TO_MEETING = 211
    MEETING_TO_DEAL = 212
    DEAL_TO_NOTE = 213
    NOTE_TO_DEAL = 214
    DEAL_TO_TASK = 215
    TASK_TO_DEAL = 216
    QUOTE_TO_TASK = 217
    TASK_TO_QUOTE = 218
    TICKET_TO_CALL = 219
    CALL_TO_TICKET = 220
    TICKET_TO_EMAIL = 223
    EMAIL_TO_TICKET = 224
    TICKET_TO_MEETING = 225
    MEETING_TO_TICKET = 226
    TICKET_TO_NOTE = 227
    NOTE_TO_TICKET = 228
    TICKET_TO_TASK = 229
    TASK_TO_TICKET = 230
    CONTACT_TO_COMPANY = 279
    COMPANY_TO_CONTACT = 280
    TICKET_TO_COMPANY = 339
    COMPANY_TO_TICKET = 340
    DEAL_TO_COMPANY = 341
    COMPANY_TO_DEAL = 342
    CALL_TO_MEETING = 399
    MEETING_TO_CALL = 400
    POSTAL_MAIL_TO_CONTACT = 453
    CONTACT_TO_POSTAL_MAIL = 454
    POSTAL_MAIL_TO_TICKET = 455
    TICKET_TO_POSTAL_MAIL = 456
    POSTAL_MAIL_TO_DEAL = 457
    DEAL_TO_POSTAL_MAIL = 458
    POSTAL_MAIL_TO_COMPANY = 459
    COMPANY_TO_POSTAL_MAIL = 460
