# coding: utf-8

"""
    Tasks

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.objects.tasks.configuration import Configuration


class SimplePublicObjectBatchInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"id_property": "str", "object_write_trace_id": "str", "id": "str", "properties": "dict[str, str]"}

    attribute_map = {"id_property": "idProperty", "object_write_trace_id": "objectWriteTraceId", "id": "id", "properties": "properties"}

    def __init__(self, id_property=None, object_write_trace_id=None, id=None, properties=None, local_vars_configuration=None):  # noqa: E501
        """SimplePublicObjectBatchInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id_property = None
        self._object_write_trace_id = None
        self._id = None
        self._properties = None
        self.discriminator = None

        if id_property is not None:
            self.id_property = id_property
        if object_write_trace_id is not None:
            self.object_write_trace_id = object_write_trace_id
        self.id = id
        self.properties = properties

    @property
    def id_property(self):
        """Gets the id_property of this SimplePublicObjectBatchInput.  # noqa: E501

        The name of a property whose values are unique for this object  # noqa: E501

        :return: The id_property of this SimplePublicObjectBatchInput.  # noqa: E501
        :rtype: str
        """
        return self._id_property

    @id_property.setter
    def id_property(self, id_property):
        """Sets the id_property of this SimplePublicObjectBatchInput.

        The name of a property whose values are unique for this object  # noqa: E501

        :param id_property: The id_property of this SimplePublicObjectBatchInput.  # noqa: E501
        :type id_property: str
        """

        self._id_property = id_property

    @property
    def object_write_trace_id(self):
        """Gets the object_write_trace_id of this SimplePublicObjectBatchInput.  # noqa: E501


        :return: The object_write_trace_id of this SimplePublicObjectBatchInput.  # noqa: E501
        :rtype: str
        """
        return self._object_write_trace_id

    @object_write_trace_id.setter
    def object_write_trace_id(self, object_write_trace_id):
        """Sets the object_write_trace_id of this SimplePublicObjectBatchInput.


        :param object_write_trace_id: The object_write_trace_id of this SimplePublicObjectBatchInput.  # noqa: E501
        :type object_write_trace_id: str
        """

        self._object_write_trace_id = object_write_trace_id

    @property
    def id(self):
        """Gets the id of this SimplePublicObjectBatchInput.  # noqa: E501

        The id to be updated. This can be the object id, or the unique property value of the idProperty property  # noqa: E501

        :return: The id of this SimplePublicObjectBatchInput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SimplePublicObjectBatchInput.

        The id to be updated. This can be the object id, or the unique property value of the idProperty property  # noqa: E501

        :param id: The id of this SimplePublicObjectBatchInput.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def properties(self):
        """Gets the properties of this SimplePublicObjectBatchInput.  # noqa: E501


        :return: The properties of this SimplePublicObjectBatchInput.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this SimplePublicObjectBatchInput.


        :param properties: The properties of this SimplePublicObjectBatchInput.  # noqa: E501
        :type properties: dict[str, str]
        """
        if self.local_vars_configuration.client_side_validation and properties is None:  # noqa: E501
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimplePublicObjectBatchInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SimplePublicObjectBatchInput):
            return True

        return self.to_dict() != other.to_dict()
