# coding: utf-8

# flake8: noqa
"""
    Associations Schema

    Associations define the relationships between objects in HubSpot. These endpoints allow you to create, read, and remove associations.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.associations.schema.models.collection_response_public_association_definition_no_paging import CollectionResponsePublicAssociationDefinitionNoPaging
from hubspot.crm.associations.schema.models.error import Error
from hubspot.crm.associations.schema.models.error_detail import ErrorDetail
from hubspot.crm.associations.schema.models.public_association_definition import PublicAssociationDefinition
