# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class MembershipsUpdateResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"record_ids_removed": "list[str]", "records_ids_added": "list[str]", "record_ids_missing": "list[str]"}

    attribute_map = {"record_ids_removed": "recordIdsRemoved", "records_ids_added": "recordsIdsAdded", "record_ids_missing": "recordIdsMissing"}

    def __init__(self, record_ids_removed=None, records_ids_added=None, record_ids_missing=None, local_vars_configuration=None):  # noqa: E501
        """MembershipsUpdateResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._record_ids_removed = None
        self._records_ids_added = None
        self._record_ids_missing = None
        self.discriminator = None

        self.record_ids_removed = record_ids_removed
        self.records_ids_added = records_ids_added
        self.record_ids_missing = record_ids_missing

    @property
    def record_ids_removed(self):
        """Gets the record_ids_removed of this MembershipsUpdateResponse.  # noqa: E501

        The IDs of the records that were `removed` from the list.  # noqa: E501

        :return: The record_ids_removed of this MembershipsUpdateResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._record_ids_removed

    @record_ids_removed.setter
    def record_ids_removed(self, record_ids_removed):
        """Sets the record_ids_removed of this MembershipsUpdateResponse.

        The IDs of the records that were `removed` from the list.  # noqa: E501

        :param record_ids_removed: The record_ids_removed of this MembershipsUpdateResponse.  # noqa: E501
        :type record_ids_removed: list[str]
        """
        if self.local_vars_configuration.client_side_validation and record_ids_removed is None:  # noqa: E501
            raise ValueError("Invalid value for `record_ids_removed`, must not be `None`")  # noqa: E501

        self._record_ids_removed = record_ids_removed

    @property
    def records_ids_added(self):
        """Gets the records_ids_added of this MembershipsUpdateResponse.  # noqa: E501


        :return: The records_ids_added of this MembershipsUpdateResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._records_ids_added

    @records_ids_added.setter
    def records_ids_added(self, records_ids_added):
        """Sets the records_ids_added of this MembershipsUpdateResponse.


        :param records_ids_added: The records_ids_added of this MembershipsUpdateResponse.  # noqa: E501
        :type records_ids_added: list[str]
        """
        if self.local_vars_configuration.client_side_validation and records_ids_added is None:  # noqa: E501
            raise ValueError("Invalid value for `records_ids_added`, must not be `None`")  # noqa: E501

        self._records_ids_added = records_ids_added

    @property
    def record_ids_missing(self):
        """Gets the record_ids_missing of this MembershipsUpdateResponse.  # noqa: E501

        The IDs of the records that were `missing` (e.g. did not exist in the portal) and so were not `added` or `removed`.  # noqa: E501

        :return: The record_ids_missing of this MembershipsUpdateResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._record_ids_missing

    @record_ids_missing.setter
    def record_ids_missing(self, record_ids_missing):
        """Sets the record_ids_missing of this MembershipsUpdateResponse.

        The IDs of the records that were `missing` (e.g. did not exist in the portal) and so were not `added` or `removed`.  # noqa: E501

        :param record_ids_missing: The record_ids_missing of this MembershipsUpdateResponse.  # noqa: E501
        :type record_ids_missing: list[str]
        """
        if self.local_vars_configuration.client_side_validation and record_ids_missing is None:  # noqa: E501
            raise ValueError("Invalid value for `record_ids_missing`, must not be `None`")  # noqa: E501

        self._record_ids_missing = record_ids_missing

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MembershipsUpdateResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MembershipsUpdateResponse):
            return True

        return self.to_dict() != other.to_dict()
