# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicRangedTimeOperation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "upper_bound_endpoint_behavior": "str",
        "include_objects_with_no_value_set": "bool",
        "upper_bound_time_point": "PublicTimePointOperationTimePoint",
        "property_parser": "str",
        "operation_type": "str",
        "type": "str",
        "lower_bound_endpoint_behavior": "str",
        "operator": "str",
        "lower_bound_time_point": "PublicTimePointOperationTimePoint",
    }

    attribute_map = {
        "upper_bound_endpoint_behavior": "upperBoundEndpointBehavior",
        "include_objects_with_no_value_set": "includeObjectsWithNoValueSet",
        "upper_bound_time_point": "upperBoundTimePoint",
        "property_parser": "propertyParser",
        "operation_type": "operationType",
        "type": "type",
        "lower_bound_endpoint_behavior": "lowerBoundEndpointBehavior",
        "operator": "operator",
        "lower_bound_time_point": "lowerBoundTimePoint",
    }

    def __init__(
        self,
        upper_bound_endpoint_behavior=None,
        include_objects_with_no_value_set=None,
        upper_bound_time_point=None,
        property_parser=None,
        operation_type=None,
        type="TIME_RANGED",
        lower_bound_endpoint_behavior=None,
        operator=None,
        lower_bound_time_point=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicRangedTimeOperation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._upper_bound_endpoint_behavior = None
        self._include_objects_with_no_value_set = None
        self._upper_bound_time_point = None
        self._property_parser = None
        self._operation_type = None
        self._type = None
        self._lower_bound_endpoint_behavior = None
        self._operator = None
        self._lower_bound_time_point = None
        self.discriminator = None

        if upper_bound_endpoint_behavior is not None:
            self.upper_bound_endpoint_behavior = upper_bound_endpoint_behavior
        self.include_objects_with_no_value_set = include_objects_with_no_value_set
        self.upper_bound_time_point = upper_bound_time_point
        if property_parser is not None:
            self.property_parser = property_parser
        self.operation_type = operation_type
        self.type = type
        if lower_bound_endpoint_behavior is not None:
            self.lower_bound_endpoint_behavior = lower_bound_endpoint_behavior
        self.operator = operator
        self.lower_bound_time_point = lower_bound_time_point

    @property
    def upper_bound_endpoint_behavior(self):
        """Gets the upper_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501


        :return: The upper_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._upper_bound_endpoint_behavior

    @upper_bound_endpoint_behavior.setter
    def upper_bound_endpoint_behavior(self, upper_bound_endpoint_behavior):
        """Sets the upper_bound_endpoint_behavior of this PublicRangedTimeOperation.


        :param upper_bound_endpoint_behavior: The upper_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501
        :type upper_bound_endpoint_behavior: str
        """

        self._upper_bound_endpoint_behavior = upper_bound_endpoint_behavior

    @property
    def include_objects_with_no_value_set(self):
        """Gets the include_objects_with_no_value_set of this PublicRangedTimeOperation.  # noqa: E501


        :return: The include_objects_with_no_value_set of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: bool
        """
        return self._include_objects_with_no_value_set

    @include_objects_with_no_value_set.setter
    def include_objects_with_no_value_set(self, include_objects_with_no_value_set):
        """Sets the include_objects_with_no_value_set of this PublicRangedTimeOperation.


        :param include_objects_with_no_value_set: The include_objects_with_no_value_set of this PublicRangedTimeOperation.  # noqa: E501
        :type include_objects_with_no_value_set: bool
        """
        if self.local_vars_configuration.client_side_validation and include_objects_with_no_value_set is None:  # noqa: E501
            raise ValueError("Invalid value for `include_objects_with_no_value_set`, must not be `None`")  # noqa: E501

        self._include_objects_with_no_value_set = include_objects_with_no_value_set

    @property
    def upper_bound_time_point(self):
        """Gets the upper_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501


        :return: The upper_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._upper_bound_time_point

    @upper_bound_time_point.setter
    def upper_bound_time_point(self, upper_bound_time_point):
        """Sets the upper_bound_time_point of this PublicRangedTimeOperation.


        :param upper_bound_time_point: The upper_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501
        :type upper_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and upper_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `upper_bound_time_point`, must not be `None`")  # noqa: E501

        self._upper_bound_time_point = upper_bound_time_point

    @property
    def property_parser(self):
        """Gets the property_parser of this PublicRangedTimeOperation.  # noqa: E501


        :return: The property_parser of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._property_parser

    @property_parser.setter
    def property_parser(self, property_parser):
        """Sets the property_parser of this PublicRangedTimeOperation.


        :param property_parser: The property_parser of this PublicRangedTimeOperation.  # noqa: E501
        :type property_parser: str
        """

        self._property_parser = property_parser

    @property
    def operation_type(self):
        """Gets the operation_type of this PublicRangedTimeOperation.  # noqa: E501


        :return: The operation_type of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """Sets the operation_type of this PublicRangedTimeOperation.


        :param operation_type: The operation_type of this PublicRangedTimeOperation.  # noqa: E501
        :type operation_type: str
        """
        if self.local_vars_configuration.client_side_validation and operation_type is None:  # noqa: E501
            raise ValueError("Invalid value for `operation_type`, must not be `None`")  # noqa: E501

        self._operation_type = operation_type

    @property
    def type(self):
        """Gets the type of this PublicRangedTimeOperation.  # noqa: E501


        :return: The type of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PublicRangedTimeOperation.


        :param type: The type of this PublicRangedTimeOperation.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["TIME_RANGED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def lower_bound_endpoint_behavior(self):
        """Gets the lower_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501


        :return: The lower_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._lower_bound_endpoint_behavior

    @lower_bound_endpoint_behavior.setter
    def lower_bound_endpoint_behavior(self, lower_bound_endpoint_behavior):
        """Sets the lower_bound_endpoint_behavior of this PublicRangedTimeOperation.


        :param lower_bound_endpoint_behavior: The lower_bound_endpoint_behavior of this PublicRangedTimeOperation.  # noqa: E501
        :type lower_bound_endpoint_behavior: str
        """

        self._lower_bound_endpoint_behavior = lower_bound_endpoint_behavior

    @property
    def operator(self):
        """Gets the operator of this PublicRangedTimeOperation.  # noqa: E501


        :return: The operator of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicRangedTimeOperation.


        :param operator: The operator of this PublicRangedTimeOperation.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    @property
    def lower_bound_time_point(self):
        """Gets the lower_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501


        :return: The lower_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501
        :rtype: PublicTimePointOperationTimePoint
        """
        return self._lower_bound_time_point

    @lower_bound_time_point.setter
    def lower_bound_time_point(self, lower_bound_time_point):
        """Sets the lower_bound_time_point of this PublicRangedTimeOperation.


        :param lower_bound_time_point: The lower_bound_time_point of this PublicRangedTimeOperation.  # noqa: E501
        :type lower_bound_time_point: PublicTimePointOperationTimePoint
        """
        if self.local_vars_configuration.client_side_validation and lower_bound_time_point is None:  # noqa: E501
            raise ValueError("Invalid value for `lower_bound_time_point`, must not be `None`")  # noqa: E501

        self._lower_bound_time_point = lower_bound_time_point

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicRangedTimeOperation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicRangedTimeOperation):
            return True

        return self.to_dict() != other.to_dict()
