# coding: utf-8

# flake8: noqa
"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.marketing.events.models.app_info import AppInfo
from hubspot.marketing.events.models.attendance_counters import AttendanceCounters
from hubspot.marketing.events.models.batch_input_marketing_event_create_request_params import BatchInputMarketingEventCreateRequestParams
from hubspot.marketing.events.models.batch_input_marketing_event_email_subscriber import BatchInputMarketingEventEmailSubscriber
from hubspot.marketing.events.models.batch_input_marketing_event_external_unique_identifier import BatchInputMarketingEventExternalUniqueIdentifier
from hubspot.marketing.events.models.batch_input_marketing_event_public_object_id_delete_request import BatchInputMarketingEventPublicObjectIdDeleteRequest
from hubspot.marketing.events.models.batch_input_marketing_event_public_update_request_full_v2 import BatchInputMarketingEventPublicUpdateRequestFullV2
from hubspot.marketing.events.models.batch_input_marketing_event_subscriber import BatchInputMarketingEventSubscriber
from hubspot.marketing.events.models.batch_response_marketing_event_public_default_response import BatchResponseMarketingEventPublicDefaultResponse
from hubspot.marketing.events.models.batch_response_marketing_event_public_default_response_v2 import BatchResponseMarketingEventPublicDefaultResponseV2
from hubspot.marketing.events.models.batch_response_marketing_event_public_default_response_v2_with_errors import BatchResponseMarketingEventPublicDefaultResponseV2WithErrors
from hubspot.marketing.events.models.batch_response_subscriber_email_response import BatchResponseSubscriberEmailResponse
from hubspot.marketing.events.models.batch_response_subscriber_vid_response import BatchResponseSubscriberVidResponse
from hubspot.marketing.events.models.collection_response_marketing_event_public_read_response_v2_forward_paging import CollectionResponseMarketingEventPublicReadResponseV2ForwardPaging
from hubspot.marketing.events.models.collection_response_search_public_response_wrapper_no_paging import CollectionResponseSearchPublicResponseWrapperNoPaging
from hubspot.marketing.events.models.collection_response_with_total_marketing_event_identifiers_response_no_paging import CollectionResponseWithTotalMarketingEventIdentifiersResponseNoPaging
from hubspot.marketing.events.models.collection_response_with_total_participation_breakdown_forward_paging import CollectionResponseWithTotalParticipationBreakdownForwardPaging
from hubspot.marketing.events.models.collection_response_with_total_public_list_no_paging import CollectionResponseWithTotalPublicListNoPaging
from hubspot.marketing.events.models.contact_association import ContactAssociation
from hubspot.marketing.events.models.crm_property_wrapper import CrmPropertyWrapper
from hubspot.marketing.events.models.error import Error
from hubspot.marketing.events.models.error_detail import ErrorDetail
from hubspot.marketing.events.models.event_detail_settings import EventDetailSettings
from hubspot.marketing.events.models.event_detail_settings_url import EventDetailSettingsUrl
from hubspot.marketing.events.models.forward_paging import ForwardPaging
from hubspot.marketing.events.models.marketing_event_association import MarketingEventAssociation
from hubspot.marketing.events.models.marketing_event_complete_request_params import MarketingEventCompleteRequestParams
from hubspot.marketing.events.models.marketing_event_create_request_params import MarketingEventCreateRequestParams
from hubspot.marketing.events.models.marketing_event_default_response import MarketingEventDefaultResponse
from hubspot.marketing.events.models.marketing_event_email_subscriber import MarketingEventEmailSubscriber
from hubspot.marketing.events.models.marketing_event_external_unique_identifier import MarketingEventExternalUniqueIdentifier
from hubspot.marketing.events.models.marketing_event_identifiers_response import MarketingEventIdentifiersResponse
from hubspot.marketing.events.models.marketing_event_public_default_response import MarketingEventPublicDefaultResponse
from hubspot.marketing.events.models.marketing_event_public_default_response_v2 import MarketingEventPublicDefaultResponseV2
from hubspot.marketing.events.models.marketing_event_public_object_id_delete_request import MarketingEventPublicObjectIdDeleteRequest
from hubspot.marketing.events.models.marketing_event_public_read_response import MarketingEventPublicReadResponse
from hubspot.marketing.events.models.marketing_event_public_read_response_v2 import MarketingEventPublicReadResponseV2
from hubspot.marketing.events.models.marketing_event_public_update_request_full_v2 import MarketingEventPublicUpdateRequestFullV2
from hubspot.marketing.events.models.marketing_event_public_update_request_v2 import MarketingEventPublicUpdateRequestV2
from hubspot.marketing.events.models.marketing_event_subscriber import MarketingEventSubscriber
from hubspot.marketing.events.models.marketing_event_update_request_params import MarketingEventUpdateRequestParams
from hubspot.marketing.events.models.next_page import NextPage
from hubspot.marketing.events.models.participation_associations import ParticipationAssociations
from hubspot.marketing.events.models.participation_breakdown import ParticipationBreakdown
from hubspot.marketing.events.models.participation_properties import ParticipationProperties
from hubspot.marketing.events.models.property_value import PropertyValue
from hubspot.marketing.events.models.public_list import PublicList
from hubspot.marketing.events.models.search_public_response_wrapper import SearchPublicResponseWrapper
from hubspot.marketing.events.models.standard_error import StandardError
from hubspot.marketing.events.models.subscriber_email_response import SubscriberEmailResponse
from hubspot.marketing.events.models.subscriber_vid_response import SubscriberVidResponse
